/**
 * Copyright (c) 2007, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 * 		Dmitry Stadnik (Borland) - initial API and implementation
 * 		Michael Golubev (Montages) - #386838 - migrate to Xtend2
 *    Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 *    Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : L1.2 clean up
 */
package xpt.navigator;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenNavigator;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.Common;
import xpt.editor.ShortcutPropertyTester;
import xpt.editor.UriEditorInputTester;

/**
 * FIXME: [MG]: xptXXX forfields
 */
@Singleton
@SuppressWarnings("all")
public class extensions {
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  private UriEditorInputTester uriTester;
  
  @Inject
  private ShortcutPropertyTester shortcutTester;
  
  @Inject
  private NavigatorAbstractNavigatorItem abstractNavigatorItem;
  
  @Inject
  private NavigatorLabelProvider labelProvider;
  
  @Inject
  private NavigatorContentProvider contentProvider;
  
  @Inject
  private DomainNavigatorContentProvider domainContentProvider;
  
  @Inject
  private DomainNavigatorLabelProvider domainLabelNavigator;
  
  @Inject
  private DomainNavigatorItem xptDomainNavigatorItem;
  
  public CharSequence extensions(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if ((it != null)) {
        CharSequence _qualifiedClassName = this.uriTester.qualifiedClassName(it);
        String _plus = ("" + _qualifiedClassName);
        CharSequence _editorInputPropertyTester = this.editorInputPropertyTester(it, "URIEditorInput", "org.eclipse.emf.common.ui.URIEditorInput", _plus);
        _builder.append(_editorInputPropertyTester);
        _builder.newLineIfNotEmpty();
        _builder.newLine();
        {
          boolean _generateShortcutIcon = it.getEditorGen().getDiagram().generateShortcutIcon();
          if (_generateShortcutIcon) {
            CharSequence _editorInputPropertyTester_1 = this.editorInputPropertyTester(it, "Shortcut", "org.eclipse.gmf.runtime.notation.View", this.shortcutTester.qualifiedClassName(it.getEditorGen().getDiagram()).toString());
            _builder.append(_editorInputPropertyTester_1);
            _builder.newLineIfNotEmpty();
          }
        }
        _builder.newLine();
        CharSequence _registerBindings = this.registerBindings(it);
        _builder.append(_registerBindings);
        _builder.newLineIfNotEmpty();
        _builder.newLine();
        String _tripleSpace = this._common.tripleSpace(1);
        _builder.append(_tripleSpace);
        _builder.append("<extension point=\"org.eclipse.ui.navigator.navigatorContent\" id=\"navigator-content\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_1 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_1);
        CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
        _builder.append(_xmlGeneratedTag);
        _builder.newLineIfNotEmpty();
        String _tripleSpace_2 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_2);
        _builder.append("<navigatorContent");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_3 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_3);
        _builder.append("id=\"");
        String _contentExtensionID = it.getContentExtensionID();
        _builder.append(_contentExtensionID);
        _builder.append("\" ");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_4 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_4);
        _builder.append("name=\"");
        String _contentExtensionName = it.getContentExtensionName();
        _builder.append(_contentExtensionName);
        _builder.append("\" ");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_5 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_5);
        _builder.append("priority=\"");
        String _contentExtensionPriority = it.getContentExtensionPriority();
        _builder.append(_contentExtensionPriority);
        _builder.append("\" ");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_6 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_6);
        _builder.append("contentProvider=\"");
        CharSequence _qualifiedClassName_1 = this.contentProvider.qualifiedClassName(it);
        _builder.append(_qualifiedClassName_1);
        _builder.append("\" ");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_7 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_7);
        _builder.append("labelProvider=\"");
        CharSequence _qualifiedClassName_2 = this.labelProvider.qualifiedClassName(it);
        _builder.append(_qualifiedClassName_2);
        _builder.append("\"");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_8 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_8);
        _builder.append("icon=\"");
        String _iconPathX = it.getEditorGen().getEditor().getIconPathX();
        _builder.append(_iconPathX);
        _builder.append("\"");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_9 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_9);
        _builder.append("activeByDefault=\"true\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_10 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_10);
        _builder.append("<triggerPoints>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_11 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_11);
        _builder.append("<or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_12 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_12);
        _builder.append("<and>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_13 = this._common.tripleSpace(6);
        _builder.append(_tripleSpace_13);
        _builder.append("<instanceof value=\"org.eclipse.core.resources.IFile\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_14 = this._common.tripleSpace(6);
        _builder.append(_tripleSpace_14);
        _builder.append("<test property=\"org.eclipse.core.resources.extension\" value=\"");
        String _diagramFileExtension = it.getEditorGen().getDiagramFileExtension();
        _builder.append(_diagramFileExtension);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_15 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_15);
        _builder.append("</and>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_16 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_16);
        _builder.append("<instanceof value=\"");
        CharSequence _qualifiedClassName_3 = this.abstractNavigatorItem.qualifiedClassName(it);
        _builder.append(_qualifiedClassName_3);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        {
          boolean _generateShortcutIcon_1 = it.getEditorGen().getDiagram().generateShortcutIcon();
          if (_generateShortcutIcon_1) {
            String _tripleSpace_17 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_17);
            _builder.append("<adapt type=\"org.eclipse.gmf.runtime.notation.View\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_18 = this._common.tripleSpace(6);
            _builder.append(_tripleSpace_18);
            _builder.append("<test property=\"");
            String _iD = it.getEditorGen().getPlugin().getID();
            _builder.append(_iD);
            _builder.append(".isShortcut\"/>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_19 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_19);
            _builder.append("</adapt>");
            _builder.newLineIfNotEmpty();
          }
        }
        String _tripleSpace_20 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_20);
        _builder.append("</or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_21 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_21);
        _builder.append("</triggerPoints>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_22 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_22);
        _builder.append("<possibleChildren>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_23 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_23);
        _builder.append("<or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_24 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_24);
        _builder.append("<instanceof value=\"");
        CharSequence _qualifiedClassName_4 = this.abstractNavigatorItem.qualifiedClassName(it);
        _builder.append(_qualifiedClassName_4);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        {
          boolean _generateShortcutIcon_2 = it.getEditorGen().getDiagram().generateShortcutIcon();
          if (_generateShortcutIcon_2) {
            String _tripleSpace_25 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_25);
            _builder.append("<adapt type=\"org.eclipse.gmf.runtime.notation.View\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_26 = this._common.tripleSpace(6);
            _builder.append(_tripleSpace_26);
            _builder.append("<test property=\"");
            String _iD_1 = it.getEditorGen().getPlugin().getID();
            _builder.append(_iD_1);
            _builder.append(".isShortcut\"/>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_27 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_27);
            _builder.append("</adapt>");
            _builder.newLineIfNotEmpty();
          }
        }
        String _tripleSpace_28 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_28);
        _builder.append("</or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_29 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_29);
        _builder.append("</possibleChildren>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_30 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_30);
        _builder.append("<commonSorter ");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_31 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_31);
        _builder.append("id=\"");
        String _sorterExtensionID = it.getSorterExtensionID();
        _builder.append(_sorterExtensionID);
        _builder.append("\" ");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_32 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_32);
        _builder.append("class=\"");
        String _sorterQualifiedClassName = it.getSorterQualifiedClassName();
        _builder.append(_sorterQualifiedClassName);
        _builder.append("\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_33 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_33);
        _builder.append("<parentExpression>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_34 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_34);
        _builder.append("<or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_35 = this._common.tripleSpace(6);
        _builder.append(_tripleSpace_35);
        _builder.append("<and>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_36 = this._common.tripleSpace(7);
        _builder.append(_tripleSpace_36);
        _builder.append("<instanceof value=\"org.eclipse.core.resources.IFile\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_37 = this._common.tripleSpace(7);
        _builder.append(_tripleSpace_37);
        _builder.append("<test property=\"org.eclipse.core.resources.extension\" value=\"");
        String _diagramFileExtension_1 = it.getEditorGen().getDiagramFileExtension();
        _builder.append(_diagramFileExtension_1);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_38 = this._common.tripleSpace(6);
        _builder.append(_tripleSpace_38);
        _builder.append("</and>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_39 = this._common.tripleSpace(6);
        _builder.append(_tripleSpace_39);
        _builder.append("<instanceof value=\"");
        CharSequence _qualifiedClassName_5 = this.abstractNavigatorItem.qualifiedClassName(it);
        _builder.append(_qualifiedClassName_5);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_40 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_40);
        _builder.append("</or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_41 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_41);
        _builder.append("</parentExpression>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_42 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_42);
        _builder.append("</commonSorter>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_43 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_43);
        _builder.append("</navigatorContent>");
        _builder.newLineIfNotEmpty();
        {
          if ((it.isGenerateDomainModelNavigator() && (null != it.getEditorGen().getDomainGenModel()))) {
            String _tripleSpace_44 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_44);
            _builder.append("<navigatorContent");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_45 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_45);
            _builder.append("id=\"");
            String _domainContentExtensionID = it.getDomainContentExtensionID();
            _builder.append(_domainContentExtensionID);
            _builder.append("\" ");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_46 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_46);
            _builder.append("name=\"");
            String _domainContentExtensionName = it.getDomainContentExtensionName();
            _builder.append(_domainContentExtensionName);
            _builder.append("\" ");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_47 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_47);
            _builder.append("priority=\"");
            String _domainContentExtensionPriority = it.getDomainContentExtensionPriority();
            _builder.append(_domainContentExtensionPriority);
            _builder.append("\" ");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_48 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_48);
            _builder.append("contentProvider=\"");
            CharSequence _qualifiedClassName_6 = this.domainContentProvider.qualifiedClassName(it);
            _builder.append(_qualifiedClassName_6);
            _builder.append("\" ");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_49 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_49);
            _builder.append("labelProvider=\"");
            CharSequence _qualifiedClassName_7 = this.domainLabelNavigator.qualifiedClassName(it);
            _builder.append(_qualifiedClassName_7);
            _builder.append("\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_50 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_50);
            _builder.append("icon=\"");
            String _iconPathX_1 = it.getEditorGen().getEditor().getIconPathX();
            _builder.append(_iconPathX_1);
            _builder.append("\"");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_51 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_51);
            _builder.append("activeByDefault=\"true\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_52 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_52);
            _builder.append("<triggerPoints>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_53 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_53);
            _builder.append("<or>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_54 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_54);
            _builder.append("<and>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_55 = this._common.tripleSpace(6);
            _builder.append(_tripleSpace_55);
            _builder.append("<instanceof value=\"org.eclipse.core.resources.IFile\"/>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_56 = this._common.tripleSpace(6);
            _builder.append(_tripleSpace_56);
            _builder.append("<test property=\"org.eclipse.core.resources.extension\" value=\"");
            String _domainFileExtension = it.getEditorGen().getDomainFileExtension();
            _builder.append(_domainFileExtension);
            _builder.append("\"/>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_57 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_57);
            _builder.append("</and>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_58 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_58);
            _builder.append("<instanceof value=\"");
            CharSequence _qualifiedClassName_8 = this.xptDomainNavigatorItem.qualifiedClassName(it);
            _builder.append(_qualifiedClassName_8);
            _builder.append("\"/>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_59 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_59);
            _builder.append("</or>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_60 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_60);
            _builder.append("</triggerPoints>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_61 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_61);
            _builder.append("<possibleChildren>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_62 = this._common.tripleSpace(4);
            _builder.append(_tripleSpace_62);
            _builder.append("<instanceof value=\"");
            CharSequence _qualifiedClassName_9 = this.xptDomainNavigatorItem.qualifiedClassName(it);
            _builder.append(_qualifiedClassName_9);
            _builder.append("\"/>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_63 = this._common.tripleSpace(3);
            _builder.append(_tripleSpace_63);
            _builder.append("</possibleChildren>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_64 = this._common.tripleSpace(2);
            _builder.append(_tripleSpace_64);
            _builder.append("</navigatorContent>");
            _builder.newLineIfNotEmpty();
          }
        }
        String _tripleSpace_65 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_65);
        _builder.append("<actionProvider");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_66 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_66);
        _builder.append("id=\"");
        String _actionProviderID = it.getActionProviderID();
        _builder.append(_actionProviderID);
        _builder.append("\"");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_67 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_67);
        _builder.append("class=\"");
        String _actionProviderQualifiedClassName = it.getActionProviderQualifiedClassName();
        _builder.append(_actionProviderQualifiedClassName);
        _builder.append("\">");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_68 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_68);
        _builder.append("<enablement>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_69 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_69);
        _builder.append("<or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_70 = this._common.tripleSpace(5);
        _builder.append(_tripleSpace_70);
        _builder.append("<instanceof value=\"");
        CharSequence _qualifiedClassName_10 = this.abstractNavigatorItem.qualifiedClassName(it);
        _builder.append(_qualifiedClassName_10);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
        {
          boolean _generateShortcutIcon_3 = it.getEditorGen().getDiagram().generateShortcutIcon();
          if (_generateShortcutIcon_3) {
            String _tripleSpace_71 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_71);
            _builder.append("<adapt type=\"org.eclipse.gmf.runtime.notation.View\">");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_72 = this._common.tripleSpace(6);
            _builder.append(_tripleSpace_72);
            _builder.append("<test property=\"");
            String _iD_2 = it.getEditorGen().getPlugin().getID();
            _builder.append(_iD_2);
            _builder.append(".isShortcut\"/>");
            _builder.newLineIfNotEmpty();
            String _tripleSpace_73 = this._common.tripleSpace(5);
            _builder.append(_tripleSpace_73);
            _builder.append("</adapt>");
            _builder.newLineIfNotEmpty();
          }
        }
        String _tripleSpace_74 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_74);
        _builder.append("</or>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_75 = this._common.tripleSpace(3);
        _builder.append(_tripleSpace_75);
        _builder.append("</enablement>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_76 = this._common.tripleSpace(2);
        _builder.append(_tripleSpace_76);
        _builder.append("</actionProvider>");
        _builder.newLineIfNotEmpty();
        String _tripleSpace_77 = this._common.tripleSpace(1);
        _builder.append(_tripleSpace_77);
        _builder.append("</extension>");
        _builder.newLineIfNotEmpty();
        _builder.newLine();
        CharSequence _registerLinkHelper = this.registerLinkHelper(it);
        _builder.append(_registerLinkHelper);
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public CharSequence editorInputPropertyTester(final GenNavigator it, final String property, final String type, final String testerClass) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t");
    String _tripleSpace = this._common.tripleSpace(1);
    _builder.append(_tripleSpace, "\t");
    _builder.append("<extension point=\"org.eclipse.core.expressions.propertyTesters\" id=\"navigator-proptest.is");
    _builder.append(property, "\t");
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_1);
    CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_2 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_2);
    _builder.append("<propertyTester");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_3 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_3);
    _builder.append("id=\"");
    String _iD = it.getEditorGen().getPlugin().getID();
    _builder.append(_iD);
    _builder.append(".");
    _builder.append(property);
    _builder.append("PropertyTester\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_4 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_4);
    _builder.append("type=\"");
    _builder.append(type);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_5 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_5);
    _builder.append("namespace=\"");
    String _iD_1 = it.getEditorGen().getPlugin().getID();
    _builder.append(_iD_1);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_6 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_6);
    _builder.append("properties=\"is");
    _builder.append(property);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_7 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_7);
    _builder.append("class=\"");
    _builder.append(testerClass);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_8 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_8);
    _builder.append("</propertyTester>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_9 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_9);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence registerBindings(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    String _tripleSpace = this._common.tripleSpace(1);
    _builder.append(_tripleSpace);
    _builder.append("<extension point=\"org.eclipse.ui.navigator.viewer\" id=\"navigator-viewbinding\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_1);
    CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_2 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_2);
    _builder.append("<viewerContentBinding viewerId=\"org.eclipse.ui.navigator.ProjectExplorer\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_3 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_3);
    _builder.append("<includes>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_4 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_4);
    _builder.append("<contentExtension pattern=\"");
    String _contentExtensionID = it.getContentExtensionID();
    _builder.append(_contentExtensionID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    {
      if ((it.isGenerateDomainModelNavigator() && (null != it.getEditorGen().getDomainGenModel()))) {
        String _tripleSpace_5 = this._common.tripleSpace(4);
        _builder.append(_tripleSpace_5);
        _builder.append("<contentExtension pattern=\"");
        String _domainContentExtensionID = it.getDomainContentExtensionID();
        _builder.append(_domainContentExtensionID);
        _builder.append("\"/>");
        _builder.newLineIfNotEmpty();
      }
    }
    String _tripleSpace_6 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_6);
    _builder.append("<contentExtension pattern=\"");
    String _linkHelperExtensionID = it.getLinkHelperExtensionID();
    _builder.append(_linkHelperExtensionID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_7 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_7);
    _builder.append("</includes>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_8 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_8);
    _builder.append("</viewerContentBinding>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_9 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_9);
    _builder.append("<viewerActionBinding viewerId=\"org.eclipse.ui.navigator.ProjectExplorer\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_10 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_10);
    _builder.append("<includes>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_11 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_11);
    _builder.append("<actionExtension pattern=\"");
    String _actionProviderID = it.getActionProviderID();
    _builder.append(_actionProviderID);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_12 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_12);
    _builder.append("</includes>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_13 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_13);
    _builder.append("</viewerActionBinding>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_14 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_14);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence registerLinkHelper(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t");
    String _tripleSpace = this._common.tripleSpace(1);
    _builder.append(_tripleSpace, "\t");
    _builder.append("<extension point=\"org.eclipse.ui.navigator.linkHelper\" id=\"navigator-linkhelper\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_1 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_1);
    CharSequence _xmlGeneratedTag = this._common.xmlGeneratedTag();
    _builder.append(_xmlGeneratedTag);
    _builder.newLineIfNotEmpty();
    String _tripleSpace_2 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_2);
    _builder.append("<linkHelper");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_3 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_3);
    _builder.append("id=\"");
    String _linkHelperExtensionID = it.getLinkHelperExtensionID();
    _builder.append(_linkHelperExtensionID);
    _builder.append("\"");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_4 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_4);
    _builder.append("class=\"");
    String _linkHelperQualifiedClassName = it.getLinkHelperQualifiedClassName();
    _builder.append(_linkHelperQualifiedClassName);
    _builder.append("\">");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_5 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_5);
    _builder.append("<editorInputEnablement>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_6 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_6);
    _builder.append("<and>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_7 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_7);
    _builder.append("<instanceof value=\"org.eclipse.emf.common.ui.URIEditorInput\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_8 = this._common.tripleSpace(5);
    _builder.append(_tripleSpace_8);
    _builder.append("<test property=\"");
    String _iD = it.getEditorGen().getPlugin().getID();
    _builder.append(_iD);
    _builder.append(".isURIEditorInput\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_9 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_9);
    _builder.append("</and>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_10 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_10);
    _builder.append("</editorInputEnablement>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_11 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_11);
    _builder.append("<selectionEnablement>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_12 = this._common.tripleSpace(4);
    _builder.append(_tripleSpace_12);
    _builder.append("<instanceof value=\"");
    CharSequence _qualifiedClassName = this.abstractNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    _builder.append("\"/>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_13 = this._common.tripleSpace(3);
    _builder.append(_tripleSpace_13);
    _builder.append("</selectionEnablement>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_14 = this._common.tripleSpace(2);
    _builder.append(_tripleSpace_14);
    _builder.append("</linkHelper>");
    _builder.newLineIfNotEmpty();
    String _tripleSpace_15 = this._common.tripleSpace(1);
    _builder.append(_tripleSpace_15);
    _builder.append("</extension>");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
}
